@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -26,10 +26,11 @@ QUrl SieveActionReturn::href() const
 
 QString SieveActionReturn::help() const
 {
-    return i18n("The \"return\" command stops processing of the immediately included script only and returns processing control to the script that includes it.");
+    return i18n(
+        "The \"return\" command stops processing of the immediately included script only and returns processing control to the script that includes it.");
 }
 
-QStringList SieveActionReturn::needRequires(QWidget */*parent*/) const
+QStringList SieveActionReturn::needRequires(QWidget * /*parent*/) const
 {
     return QStringList() << QStringLiteral("include");
 }
