@@ -1,27 +1,25 @@
 /*
-  SPDX-FileCopyrightText: 2016-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-only
 */
 
 #include "sieveeditorwebengineview.h"
-#include <qtwebenginewidgetsversion.h>
 
 #include <KLocalizedString>
 #include <QContextMenuEvent>
-#include <QMenu>
 #include <QFileDialog>
+#include <QMenu>
 #include <QWebEngineDownloadItem>
 #include <QWebEngineProfile>
 #include <QWebEngineSettings>
-#include <QtWebEngineWidgets>
 using namespace KSieveUi;
 
 SieveEditorWebEngineView::SieveEditorWebEngineView(QWidget *parent)
     : QWebEngineView(parent)
 {
-    auto *profile = new QWebEngineProfile(this);
-    auto *page = new QWebEnginePage(profile, this);
+    auto profile = new QWebEngineProfile(this);
+    auto page = new QWebEnginePage(profile, this);
     page->settings()->setAttribute(QWebEngineSettings::JavascriptEnabled, false);
     page->settings()->setAttribute(QWebEngineSettings::PluginsEnabled, false);
     page->settings()->setAttribute(QWebEngineSettings::AutoLoadImages, true);
@@ -50,12 +48,8 @@ void SieveEditorWebEngineView::downloadRequested(QWebEngineDownloadItem *downloa
     const QString filename = QFileDialog::getSaveFileName(this, i18n("Save Web Page"));
     if (!filename.isEmpty()) {
         download->setSavePageFormat(QWebEngineDownloadItem::SingleHtmlSaveFormat);
-#if QTWEBENGINEWIDGETS_VERSION >= QT_VERSION_CHECK(5, 14, 0)
         download->setDownloadDirectory(QFileInfo(filename).path());
         download->setDownloadFileName(QFileInfo(filename).fileName());
-#else
-        download->setPath(filename);
-#endif
         download->accept();
     } else {
         download->cancel();
@@ -75,7 +69,7 @@ void SieveEditorWebEngineView::contextMenuEvent(QContextMenuEvent *ev)
     }
 
     if (!menu.actions().isEmpty()) {
-        auto *separator = new QAction(&menu);
+        auto separator = new QAction(&menu);
         separator->setSeparator(true);
         menu.addAction(separator);
     }
@@ -86,7 +80,7 @@ void SieveEditorWebEngineView::contextMenuEvent(QContextMenuEvent *ev)
     }
 
     if (!menu.actions().isEmpty()) {
-        auto *separator = new QAction(&menu);
+        auto separator = new QAction(&menu);
         separator->setSeparator(true);
         menu.addAction(separator);
     }
@@ -105,7 +99,7 @@ void SieveEditorWebEngineView::contextMenuEvent(QContextMenuEvent *ev)
     }
     act = pageAction(QWebEnginePage::SavePage);
     if (act->isEnabled()) {
-        auto *separator = new QAction(&menu);
+        auto separator = new QAction(&menu);
         separator->setSeparator(true);
         menu.addAction(separator);
         menu.addAction(act);
@@ -115,6 +109,6 @@ void SieveEditorWebEngineView::contextMenuEvent(QContextMenuEvent *ev)
 
 QWebEngineView *SieveEditorWebEngineView::createWindow(QWebEnginePage::WebWindowType type)
 {
-    Q_UNUSED(type);
+    Q_UNUSED(type)
     return this;
 }
