@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2016-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -69,12 +69,8 @@ KSieveUi::SieveImapAccountSettings::AuthenticationMode SieveImapAccountSettings:
 
 bool SieveImapAccountSettings::operator==(const SieveImapAccountSettings &other) const
 {
-    return (mServerName == other.serverName())
-           && (mPassword == other.password())
-           && (mPort == other.port())
-           && (mUserName == other.userName())
-           && (mAuthenticationType == other.authenticationType())
-           && (mEncryptionMode == other.encryptionMode());
+    return (mServerName == other.serverName()) && (mPassword == other.password()) && (mPort == other.port()) && (mUserName == other.userName())
+        && (mAuthenticationType == other.authenticationType()) && (mEncryptionMode == other.encryptionMode());
 }
 
 bool SieveImapAccountSettings::isValid() const
@@ -92,7 +88,7 @@ void SieveImapAccountSettings::setEncryptionMode(SieveImapAccountSettings::Encry
     mEncryptionMode = encryptionMode;
 }
 
-QDebug operator <<(QDebug d, const SieveImapAccountSettings &settings)
+QDebug operator<<(QDebug d, const SieveImapAccountSettings &settings)
 {
     d << "serverName " << settings.serverName();
     d << "userName " << settings.userName();
